@@ -1,3 +1,4 @@
+import time
 from typing import Any, List
 
 from ..cache import Cache, with_cache
@@ -6,7 +7,7 @@ from .types import GoogleApiServiceusageV1Service
 
 
 @with_cache("serviceusage", "services")
-def _all(project_id: str) -> List[Any]:
+def _all_enabled(project_id: str) -> List[Any]:
     """
     Get the list of services for a project.
 
@@ -20,17 +21,18 @@ def _all(project_id: str) -> List[Any]:
 
     services = []
 
-    request = api.services.list(parent=f"projects/{project_id}")
+    request = api.services.list(parent=f"projects/{project_id}", filter="state:ENABLED")
 
     while request is not None:
-        response = request.execute()
+        # Allow a few retries to avoid rate-limiting
+        response = request.execute(num_retries=3)
         services.extend(response.get("services", []))
         request = api.services.list_next(request, response)
 
     return services
 
 
-def all(project_id: str, cache: Cache) -> List[GoogleApiServiceusageV1Service]:
+def all_enabled(project_id: str, cache: Cache) -> List[GoogleApiServiceusageV1Service]:
     """
     Get the list of services for a project.
 
@@ -42,7 +44,9 @@ def all(project_id: str, cache: Cache) -> List[GoogleApiServiceusageV1Service]:
         A list of services.
     """
 
-    return [GoogleApiServiceusageV1Service(**service) for service in _all(cache, project_id)]
+    return [
+        GoogleApiServiceusageV1Service(**service) for service in _all_enabled(cache, project_id)
+    ]
 
 
 Mapping = {
